/******************************************************************************/
/*                                                                            */
/*                  SAS Program to Score the prePIRLS Items                   */
/*                           PIRLS 2011 User Guide                            */
/*                                                                            */
/******************************************************************************/

OPTIONS NONOTES ;

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <path> must be edited ;

LIBNAME LIBDAT "<path>" ;

* Specify the list of countries to be processed ;

%LET COUNTRY = BWA COL ZAF ;

* List of multiple-choice items with A key ;

%LET ARIGHT = L11A03M   L11A08M   L11A13MB  L11A13MC  L11A13MD  L11B04M   L11B14M
              L11C05M   L11C10M   L11D06M   L11L06M   L11L10M   L11O12M   L11O16M
              L11P02M   L11U05M   L11U08M   ;

* List of multiple-choice items with B key ;

%LET BRIGHT = L11A05M   L11A13ME  L11B06M   L11B12M   L11C04M   L11C12M   L11D02M
              L11D11M   L11D14M   L11L07M   L11L08M   L11O04M   L11O07M   L11P08M
              L11P10M   L11U02M   L11U13M   ;

* List of multiple-choice items with C key ;

%LET CRIGHT = L11A01M   L11B09M   L11C06M   L11C14M   L11D13M   L11L02M   L11L04M
              L11O01M   L11O08M   L11P01M   L11P09M   L11U07M   L11U09M   ;

* List of multiple-choice items with D key ;

%LET DRIGHT = L11A14M   L11C11M   L11C13M   L11D07M   L11D08M   L11L05M   L11L09M
              L11L12M   L11O03M   L11O13M   L11P05M   L11U03M   L11U06M   ;

* List of constructed-response items ;

%LET CONSTR = L11A02C   L11A04C   L11A06C   L11A07C   L11A09C   L11A10C   L11A11C
              L11A12CA  L11A12CB  L11A12CC  L11A12CZ  L11A13CZ  L11B01C   L11B02C
              L11B03C   L11B05C   L11B07C   L11B08C   L11B10C   L11B11C   L11B15C
              L11B16C   L11B17C   L11B18C   L11C01C   L11C02C   L11C03C   L11C07C
              L11C08C   L11C09C   L11C15C   L11C16C   L11D01C   L11D03C   L11D04C
              L11D05C   L11D09C   L11D10C   L11D12C   L11D15C   L11D16C   L11L01C
              L11L03C   L11L11C   L11L13C   L11L14C   L11L15C   L11O02C   L11O05C
              L11O06C   L11O09C   L11O10C   L11O11C   L11O14C   L11O15C   L11P03C
              L11P04C   L11P06C   L11P07C   L11P11C   L11P12C   L11P13C   L11P14C
              L11U01C   L11U04C   L11U10C   L11U11C   L11U12C   L11U14C   ;

%MACRO SCOREIT (ITEM, TYPE, RIGHT, NR, NA, OM, OTHER) ;

   * Code for multiple-choice items ;

   %IF %UPCASE(&TYPE) = "MC" %THEN %DO ;
      SCORE = 0 ;
         IF &ITEM = &RIGHT THEN SCORE = 1 ;
         IF &ITEM = &NR    THEN SCORE = 0 ; * Not Reached ;
         IF &ITEM = &NA    THEN SCORE = . ; * Not Administered ;
         IF &ITEM = &OM    THEN SCORE = 0 ; * Omitted ;
         IF &ITEM = &OTHER THEN SCORE = 0 ; * Other Missing ;
      &ITEM = SCORE ;
   %END ;

   * Code for constructed-response items ;

   %IF %UPCASE(&TYPE) = "CR" %THEN %DO ;
      SCORE = 0 ;
         IF &ITEM = 3      THEN SCORE = 3 ;
         IF &ITEM = 2      THEN SCORE = 2 ;
         IF &ITEM = 1      THEN SCORE = 1 ;
         IF &ITEM = 0      THEN SCORE = 0 ;
         IF &ITEM = &NR    THEN SCORE = 0 ; * Not Reached ;
         IF &ITEM = &NA    THEN SCORE = . ; * Not Administered ;
         IF &ITEM = &OM    THEN SCORE = 0 ; * Omitted ;
         IF &ITEM = &OTHER THEN SCORE = 0 ; * Other Missing ;
      &ITEM = SCORE ;
   %END ;

%MEND SCOREIT ;

%MACRO DOIT ;

   * Start of country processing loop ;

   %LET I = 1 ;
   %DO %WHILE(%LENGTH(%SCAN(&COUNTRY,&I))) ;
      %LET CTRY = %SCAN(&COUNTRY,&I) ;

      * Get the student achievement data ;

      DATA LIBDAT.ASC&CTRY.L1; * Output File ;
           SET LIBDAT.ASA&CTRY.L1; * Input File  ;

           ARRAY ARIGHT &ARIGHT ;
           ARRAY BRIGHT &BRIGHT ;
           ARRAY CRIGHT &CRIGHT ;
           ARRAY DRIGHT &DRIGHT ;
           ARRAY CONSTR &CONSTR ;

           DO OVER ARIGHT ; %SCOREIT (ARIGHT, "MC", 1, .R, .A, ., .I) ; END ;
           DO OVER BRIGHT ; %SCOREIT (BRIGHT, "MC", 2, .R, .A, ., .I) ; END ;
           DO OVER CRIGHT ; %SCOREIT (CRIGHT, "MC", 3, .R, .A, ., .I) ; END ;
           DO OVER DRIGHT ; %SCOREIT (DRIGHT, "MC", 4, .R, .A, ., .I) ; END ;
           DO OVER CONSTR ; %SCOREIT (CONSTR, "CR",  , .R, .A, ., .I) ; END ;

      RUN ;

      * End of country processing loop ;

      %LET I = %EVAL(&I + 1) ;
   %END ;

%MEND DOIT ;

%DOIT ;
