/******************************************************************************/
/*                                                                            */
/*                 SAS Program to Score the PIRLS 2011 Items                  */
/*                           PIRLS 2011 User Guide                            */
/*                                                                            */
/******************************************************************************/

OPTIONS NONOTES ;

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <path> must be edited ;

LIBNAME LIBDAT "<path>" ;

* Specify the list of countries to be processed ;

%LET COUNTRY = AUS AUT AZE BFR BGR CAN TWN COL HRV CZE
               DNK ENG FIN FRA GEO DEU HKG HUN IDN IRN
               IRL ISR ITA LTU MLT MAR NLD NZL NIR NOR
               OMN PRT POL QAT ROM RUS SAU SGP SVK SVN
               ESP SWE TTO ARE USA
               BWA HND KWT MA6
               CAB COT CQU MLN ZAF EAN AAD ADU UFL ;

* List of multiple-choice items with A key ;

%LET ARIGHT = R21E01M   R21E03M   R21E06M   R21E11M   R11F04M   R11F11M   R31G05M
              R31G11M   R11L05M   R31M03M   R31M05M   R31M11M   R21N05M   R21N09M
              R31P11M   R31P12M   R31W09M   R31W12M   R21Y06M   ;

* List of multiple-choice items with B key ;

%LET BRIGHT = R11F01M   R11F13M   R31G03M   R31G06M   R21K06M   R21K09M   R21K11M
              R11L02M   R31M01M   R31M07M   R31M15M   R21N04M   R21N06M   R31P04M
              R31W08M   R21Y01M   R21Y04M   R21Y05M   R21Y07M   R21Y11M   ;

* List of multiple-choice items with C key ;

%LET CRIGHT = R21E02M   R21E04M   R11F02M   R31G01M   R31G09M   R21K03M   R11L01M
              R11L07M   R11L09M   R31M06M   R31M12M   R31M13M   R21N01M   R21N07M
              R31P08M   R31P10M   R31W03M   R31W05M   R31W06M   R21Y08M   ;

* List of multiple-choice items with D key ;

%LET DRIGHT = R21E08M   R11F03M   R11F05M   R31G07M   R31G14M   R21K04M   R21K08M
              R11L11M   R31M08M   R31M14M   R21N10M   R31P01M   R31P13M   R31W10M
              R21Y02M   ;

* List of constructed-response items ;

%LET CONSTR = R21E05C   R21E07C   R21E09C   R21E10C   R21E12C   R11F06C   R11F07C
              R11F08C   R11F09C   R11F10C   R11F12C   R31G02C   R31G04C   R31G08CA
              R31G08CB  R31G08CZ  R31G10C   R31G12C   R31G13CA  R31G13CB  R31G13CC
              R31G13CZ  R21K01C   R21K02C   R21K05C   R21K07C   R21K10C   R21K12C
              R11L03C   R11L04C   R11L06C   R11L08C   R11L10C   R11L12C   R31M02C
              R31M04C   R31M09C   R31M10C   R31M16C   R31M17CA  R31M17CB  R31M17CC
              R31M17CZ  R21N02C   R21N03C   R21N08C   R21N11C   R21N12C   R31P02C
              R31P03C   R31P05C   R31P06C   R31P07C   R31P09C   R31P14C   R31P15C
              R31P16C   R31W01C   R31W02C   R31W04C   R31W07CA  R31W07CB  R31W07CC
              R31W07CZ  R31W11C   R31W13C   R21Y03C   R21Y09C   R21Y10C   R21Y12C
              R21Y13C   R21Y14C   ;

%MACRO SCOREIT (ITEM, TYPE, RIGHT, NR, NA, OM, OTHER) ;

   * Code for multiple-choice items ;

   %IF %UPCASE(&TYPE) = "MC" %THEN %DO ;
      SCORE = 0 ;
         IF &ITEM = &RIGHT THEN SCORE = 1 ;
         IF &ITEM = &NR    THEN SCORE = 0 ; * Not Reached ;
         IF &ITEM = &NA    THEN SCORE = . ; * Not Administered ;
         IF &ITEM = &OM    THEN SCORE = 0 ; * Omitted ;
         IF &ITEM = &OTHER THEN SCORE = 0 ; * Other Missing ;
      &ITEM = SCORE ;
   %END ;

   * Code for constructed-response items ;

   %IF %UPCASE(&TYPE) = "CR" %THEN %DO ;
      SCORE = 0 ;
         IF &ITEM = 3      THEN SCORE = 3 ;
         IF &ITEM = 2      THEN SCORE = 2 ;
         IF &ITEM = 1      THEN SCORE = 1 ;
         IF &ITEM = 0      THEN SCORE = 0 ;
         IF &ITEM = &NR    THEN SCORE = 0 ; * Not Reached ;
         IF &ITEM = &NA    THEN SCORE = . ; * Not Administered ;
         IF &ITEM = &OM    THEN SCORE = 0 ; * Omitted ;
         IF &ITEM = &OTHER THEN SCORE = 0 ; * Other Missing ;
      &ITEM = SCORE ;
   %END ;

%MEND SCOREIT ;

%MACRO DOIT ;

   * Start of country processing loop ;

   %LET I = 1 ;
   %DO %WHILE(%LENGTH(%SCAN(&COUNTRY,&I))) ;
      %LET CTRY = %SCAN(&COUNTRY,&I) ;

      * Get the student achievement data ;

      DATA LIBDAT.ASC&CTRY.R3; * Output File ;
           SET LIBDAT.ASA&CTRY.R3; * Input File  ;

           ARRAY ARIGHT &ARIGHT ;
           ARRAY BRIGHT &BRIGHT ;
           ARRAY CRIGHT &CRIGHT ;
           ARRAY DRIGHT &DRIGHT ;
           ARRAY CONSTR &CONSTR ;

           DO OVER ARIGHT ; %SCOREIT (ARIGHT, "MC", 1, .R, .A, ., .I) ; END ;
           DO OVER BRIGHT ; %SCOREIT (BRIGHT, "MC", 2, .R, .A, ., .I) ; END ;
           DO OVER CRIGHT ; %SCOREIT (CRIGHT, "MC", 3, .R, .A, ., .I) ; END ;
           DO OVER DRIGHT ; %SCOREIT (DRIGHT, "MC", 4, .R, .A, ., .I) ; END ;
           DO OVER CONSTR ; %SCOREIT (CONSTR, "CR",  , .R, .A, ., .I) ; END ;

      RUN ;

      * End of country processing loop ;

      %LET I = %EVAL(&I + 1) ;
   %END ;

%MEND DOIT ;

%DOIT ;
