/******************************************************************************/
/*                                                                            */
/*              SAS Program for PIRLS 2011 User Guide Example 5               */
/*        PIRLS 2011 International Results in Mathematics Exhibit 7.6         */
/*                                                                            */
/******************************************************************************/

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME P11 "<datpath>" ;

* Issue the include command to include the JACKGPV macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKPV.SAS" ;

* Get and sort the teacher data ;

PROC SORT DATA = P11.ATGALLR3 OUT = ATGALLR3 ;
     BY IDCNTRY IDTEACH IDLINK ;
RUN ;

* Get and sort the student-teacher linkage data ;

PROC SORT DATA = P11.ASTALLR3 OUT = ASTALLR3 ;
     BY IDCNTRY IDTEACH IDLINK ;
RUN ;

* Merge the two files ;

DATA ATGMERGED ;
     MERGE ATGALLR3 (IN = INATG)
           ASTALLR3 (IN = INAST) ;
     BY IDCNTRY IDTEACH IDLINK ;
     IF INATG AND INAST ;
RUN ;

* Read the merged file and select cases of interest ;

DATA ATGMERGED ;
     SET ATGMERGED ;

     * Select cases with no missing data ;

     WHERE NMISS (ATDG01) = 0 ;

RUN ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

 VALUE COUNTRY
   036 = "AUSTRALIA"
   040 = "AUSTRIA"
   031 = "AZERBAIJAN"
   957 = "BELGIUM (FRENCH)"
   100 = "BULGARIA"
   124 = "CANADA"
   158 = "CHINESE TAIPEI"
   170 = "COLOMBIA"
   191 = "CROATIA"
   203 = "CZECH REPUBLIC"
   208 = "DENMARK"
   926 = "ENGLAND"
   246 = "FINLAND"
   250 = "FRANCE"
   268 = "GEORGIA"
   276 = "GERMANY"
   344 = "HONG KONG SAR"
   348 = "HUNGARY"
   360 = "INDONESIA"
   364 = "IRAN, ISLAMIC REP. OF"
   372 = "IRELAND"
   376 = "ISRAEL"
   380 = "ITALY"
   440 = "LITHUANIA"
   470 = "MALTA"
   504 = "MOROCCO"
   528 = "NETHERLANDS"
   554 = "NEW ZEALAND"
   928 = "NORTHERN IRELAND"
   578 = "NORWAY"
   512 = "OMAN"
   616 = "POLAND"
   620 = "PORTUGAL"
   634 = "QATAR"
   642 = "ROMANIA"
   643 = "RUSSIAN FEDERATION"
   682 = "SAUDI ARABIA"
   702 = "SINGAPORE"
   703 = "SLOVAK REPUBLIC"
   705 = "SLOVENIA"
   724 = "SPAIN"
   752 = "SWEDEN"
   780 = "TRINIDAD AND TOBAGO"
   784 = "UNITED ARAB EMIRATES"
   840 = "UNITED STATES"
   072 = "BOTSWANA"
   340 = "HONDURAS"
   414 = "KUWAIT"
  6504 = "MOROCCO (6)"
  9134 = "ALBERTA, CANADA"
  9132 = "ONTARIO, CANADA"
  9133 = "QUEBEC, CANADA"
  9470 = "MALTESE - MALTA"
   710 = "ENG/AFR (5) - RSA"
 72401 = "ANDALUSIA, SPAIN"
  7842 = "ABU DHABI, UAE"
  7841 = "DUBAI, UAE"
 11200 = "FLORIDA, US" ;

 VALUE ATDG
     1 = "20 YEARS OR MORE"
     2 = "AT LEAST 10 BUT LESS THAN 20 YEARS"
     3 = "AT LEAST 5 BUT LESS THAN 10 YEARS"
     4 = "LESS THAN 5 YEARS" ;

RUN ;

* Invoke the JACKPV macro to compute the statistics ;

%JACKPV (TCHWGT, JKZONE, JKREP, 75, IDCNTRY ATDG01, ASRREA0, 5, ATGMERGED) ;

* Print the results ;

PROC PRINT DATA = FINAL NOOBS ;
     VAR IDCNTRY ATDG01 N TCHWGT MNPV MNPV_SE PCT PCT_SE ;
     FORMAT IDCNTRY COUNTRY. ATDG01 ATDG. N 6.0 TCHWGT 10.0
            MNPV MNPV_SE PCT PCT_SE 6.2 ;
RUN ;
