/******************************************************************************/
/*                                                                            */
/*       SAS Program to Join SAS Data Files into a Single SAS Data File       */
/*                           PIRLS 2011 User Guide                            */
/*                                                                            */
/******************************************************************************/

OPTIONS NONOTES ;

* Specify the study ;
* <study> must be edited: R3 for PIRLS, L1 for prePIRLS ;

%LET STUDY = <study> ;

* Specify the file type ;
* <type> must be edited ;

%LET TYPE = <type> ;

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <path> must be edited ;

LIBNAME LIBDAT "<path>" ;

%MACRO DOIT ;

   * Specify the list of countries to be processed ;

   %IF %UPCASE(%SUBSTR(&STUDY,1,1)) = R %THEN %DO ; * PIRLS countries ;

      %LET COUNTRY = AUS AUT AZE BFR BGR CAN TWN COL HRV CZE
                     DNK ENG FIN FRA GEO DEU HKG HUN IDN IRN
                     IRL ISR ITA LTU MLT MAR NLD NZL NIR NOR
                     OMN PRT POL QAT ROM RUS SAU SGP SVK SVN
                     ESP SWE TTO ARE USA
                     BWA HND KWT MA6
                     CAB COT CQU MLN ZAF EAN AAD ADU UFL ;

   %END ;

   %IF %UPCASE(%SUBSTR(&STUDY,1,1)) = L %THEN %DO ; * prePIRLS countries ;

      %LET COUNTRY = BWA COL ZAF ;

   %END ;

   DATA &TYPE.ALL&STUDY ;
        SET %LET I = 1 ;
            %DO %WHILE(%LENGTH(%SCAN(&COUNTRY,&I))) ;
               %LET CTRY = %SCAN(&COUNTRY,&I) ;
                  LIBDAT.&TYPE&CTRY&STUDY
               %LET I = %EVAL(&I + 1) ;
            %END ; ;
   RUN ;

   * Specify the sorting variables ;
   * Dependent of the file type ;

   %LET SORTVARS = IDCNTRY IDSTUD ;

   %IF %UPCASE(%SUBSTR(&TYPE,2,1)) = C %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDSCHOOL ; %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,2,1)) = T %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDTEACH IDLINK ; %END ;

   %IF %UPCASE(%SUBSTR(&TYPE,3,1)) = T %THEN %DO ;
      %LET SORTVARS = IDCNTRY IDSTUD IDTEACH IDLINK ; %END ;

   PROC SORT DATA=&TYPE.ALL&STUDY OUT=LIBDAT.&TYPE.ALL&STUDY ;
        BY &SORTVARS ;
   RUN ;

%MEND DOIT ;

%DOIT ;
