/******************************************************************************/
/*                                                                            */
/*               Sample SAS Program to Invoke the JACKPV Macro                */
/*                           PIRLS 2011  User Guide                           */
/*                                                                            */
/******************************************************************************/

* Specify the study ;
* <study> must be edited: R3 for PIRLS, L1 for prePIRLS ;

%LET STUDY = <study> ;

* Specify the path for the SAS data files following the format x:\xxx\ ;
* <datpath> must be edited ;

LIBNAME P11 "<datpath>" ;

* Issue the include command to include the JACKPV macro in the program ;
* <macpath> must be edited following the format x:\xxx\ ;

%INCLUDE "<macpath>JACKPV.SAS" ;

* Get the student data and select cases of interest ;

DATA ASGALL&STUDY ;
     SET P11.ASGALL&STUDY ;

     * Select cases with no missing data ;

     WHERE NMISS (ITSEX) = 0 ;

RUN ;

* Define formats for the variables used ;

PROC FORMAT LIBRARY = WORK ;

%IF %UPCASE(%SUBSTR(&STUDY,1,1)) = R %THEN %DO ;
 VALUE COUNTRY
   036 = "AUSTRALIA"
   040 = "AUSTRIA"
   031 = "AZERBAIJAN"
   957 = "BELGIUM (FRENCH)"
   100 = "BULGARIA"
   124 = "CANADA"
   158 = "CHINESE TAIPEI"
   170 = "COLOMBIA"
   191 = "CROATIA"
   203 = "CZECH REPUBLIC"
   208 = "DENMARK"
   926 = "ENGLAND"
   246 = "FINLAND"
   250 = "FRANCE"
   268 = "GEORGIA"
   276 = "GERMANY"
   344 = "HONG KONG SAR"
   348 = "HUNGARY"
   360 = "INDONESIA"
   364 = "IRAN, ISLAMIC REP. OF"
   372 = "IRELAND"
   376 = "ISRAEL"
   380 = "ITALY"
   440 = "LITHUANIA"
   470 = "MALTA"
   504 = "MOROCCO"
   528 = "NETHERLANDS"
   554 = "NEW ZEALAND"
   928 = "NORTHERN IRELAND"
   578 = "NORWAY"
   512 = "OMAN"
   616 = "POLAND"
   620 = "PORTUGAL"
   634 = "QATAR"
   642 = "ROMANIA"
   643 = "RUSSIAN FEDERATION"
   682 = "SAUDI ARABIA"
   702 = "SINGAPORE"
   703 = "SLOVAK REPUBLIC"
   705 = "SLOVENIA"
   724 = "SPAIN"
   752 = "SWEDEN"
   780 = "TRINIDAD AND TOBAGO"
   784 = "UNITED ARAB EMIRATES"
   840 = "UNITED STATES"
   072 = "BOTSWANA (6)"
   340 = "HONDURAS (6)"
   414 = "KUWAIT (6)"
  6504 = "MOROCCO (6)"
  9134 = "ALBERTA, CANADA"
  9132 = "ONTARIO, CANADA"
  9133 = "QUEBEC, CANADA"
  9470 = "MALTESE - MALTA"
   710 = "ENG/AFR (5) - RSA"
 72401 = "ANDALUSIA, SPAIN"
  7842 = "ABU DHABI, UAE"
  7841 = "DUBAI, UAE"
 11200 = "FLORIDA, US" ;
%END ;

%IF %UPCASE(%SUBSTR(&STUDY,1,1)) = L %THEN %DO ;
 VALUE COUNTRY
   072 = "BOTSWANA"
   170 = "COLOMBIA"
   710 = "SOUTH AFRICA" ;
%END ;

 VALUE SEX
     1 = "GIRL"
     2 = "BOY" ;

RUN ;

* Invoke the JACKPV macro to compute the statistics ;

%JACKPV (TOTWGT, JKZONE, JKREP, 75, IDCNTRY ITSEX, ASRREA0, 5, ASGALL&STUDY) ;

* Print the results ;

PROC PRINT DATA = FINAL NOOBS ;
     VAR IDCNTRY ITSEX N TOTWGT MNPV MNPV_SE PCT PCT_SE ;
     FORMAT IDCNTRY COUNTRY. ITSEX SEX. N 6.0 TOTWGT 10.0
            MNPV MNPV_SE PCT PCT_SE 6.2 ;
RUN ;
