*                                                                              .
*                  SPSS Program to Score the PIRLS 2011 Items                  .
*                            PIRLS 2011 User Guide                             .
*                                                                              .

SET MPRINT=ON.

DEFINE SCOREIT (TYPE  = !CHAREND('/') /
                ITEM  = !CHAREND('/') /
                RIGHT = !CHAREND('/') /
                NR    = !CHAREND('/') /
                NA    = !CHAREND('/') /
                OM    = !CHAREND('/') /
                OTHER = !CHAREND('/') ) .

* Code for multiple-choice items .

 !IF (!UPCASE(!TYPE)=MC) !THEN
    !DO !I !IN (!ITEM) .
       RECODE !I (!RIGHT = 1      )
                 (!NR    = 0      ) /* Not Reached      */
                 (!NA    = SYSMIS ) /* Not Administered */
                 (!OM    = 0      ) /* Omitted          */
                 (!OTHER = 0      ) /* Other Missing    */
                 (ELSE   = 0      ) .
    !DOEND .
 !IFEND .

 * Code for constructed-response items .

 !IF (!UPCASE(!TYPE)=CR) !THEN
    !DO !I !IN (!ITEM) .
       RECODE !I (3      = 3      )
                 (2      = 2      )
                 (1      = 1      )
                 (0      = 0      )
                 (!NR    = 0      ) /* Not Reached      */
                 (!NA    = SYSMIS ) /* Not Administered */
                 (!OM    = 0      ) /* Omitted          */
                 (!OTHER = 0      ) /* Other Missing    */
                 (ELSE   = 0      ) .
    !DOEND .
 !IFEND .

!ENDDEFINE .

DEFINE DOIT (COUNTRY = !CHAREND('/') ) .

* Specify the path for the SPSS data files following the format x:\xxx\ .
* <path> must be edited .

!LET !LIBDAT = !UNQUOTE("<path>") .

* Country loop .

!DO !CTY !IN (!COUNTRY) .

* Get the student achievement data .

ADD FILES
  / FILE = !QUOTE(!CONCAT(!LIBDAT,'ASA',!CTY,'M5.SAV')) .

* Score multiple-choice items with A key .

SCOREIT  Type  = MC      /
         Item  = R21E01M   R21E03M   R21E06M   R21E11M   R11F04M   R11F11M   R31G05M
                 R31G11M   R11L05M   R31M03M   R31M05M   R31M11M   R21N05M   R21N09M
                 R31P11M   R31P12M   R31W09M   R31W12M   R21Y06M   /
         RIGHT = 1       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with B key .

SCOREIT  Type  = MC      /
         Item  = R11F01M   R11F13M   R31G03M   R31G06M   R21K06M   R21K09M   R21K11M
                 R11L02M   R31M01M   R31M07M   R31M15M   R21N04M   R21N06M   R31P04M
                 R31W08M   R21Y01M   R21Y04M   R21Y05M   R21Y07M   R21Y11M   /
         RIGHT = 2       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with C key .

SCOREIT  Type  = MC      /
         Item  = R21E02M   R21E04M   R11F02M   R31G01M   R31G09M   R21K03M   R11L01M
                 R11L07M   R11L09M   R31M06M   R31M12M   R31M13M   R21N01M   R21N07M
                 R31P08M   R31P10M   R31W03M   R31W05M   R31W06M   R21Y08M   /
         RIGHT = 3       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score multiple-choice items with D key .

SCOREIT  Type  = MC       /
         Item  = R21E08M   R11F03M   R11F05M   R31G07M   R31G14M   R21K04M   R21K08M
                 R11L11M   R31M08M   R31M14M   R21N10M   R31P01M   R31P13M   R31W10M
                 R21Y02M   /
         RIGHT = 4       /
         NR    = 6       /
         NA    = sysmis  /
         OM    = 9       /
         OTHER = 7       .

* Score Constructed-Response Items .

SCOREIT  Type  = CR      /
         Item  = R21E05C   R21E07C   R21E09C   R21E10C   R21E12C   R11F06C   R11F07C
                 R11F08C   R11F09C   R11F10C   R11F12C   R31G02C   R31G04C   R31G08CA
                 R31G08CB  R31G08CZ  R31G10C   R31G12C   R31G13CA  R31G13CB  R31G13CC
                 R31G13CZ  R21K01C   R21K02C   R21K05C   R21K07C   R21K10C   R21K12C
                 R11L03C   R11L04C   R11L06C   R11L08C   R11L10C   R11L12C   R31M02C
                 R31M04C   R31M09C   R31M10C   R31M16C   R31M17CA  R31M17CB  R31M17CC
                 R31M17CZ  R21N02C   R21N03C   R21N08C   R21N11C   R21N12C   R31P02C
                 R31P03C   R31P05C   R31P06C   R31P07C   R31P09C   R31P14C   R31P15C
                 R31P16C   R31W01C   R31W02C   R31W04C   R31W07CA  R31W07CB  R31W07CC
                 R31W07CZ  R31W11C   R31W13C   R21Y03C   R21Y09C   R21Y10C   R21Y12C
                 R21Y13C   R21Y14C   /
         RIGHT =  0      /
         NR    = 96      /
         NA    = sysmis  /
         OM    = 99      /
         OTHER = 90      .

EXECUTE.

* Save the student data .

SAVE OUTFILE = !QUOTE(!CONCAT(!LIBDAT,'ASC',!CTY,'M5.SAV')) .

!DOEND .

!ENDDEFINE .

* Specify the list of countries to be processed .

DOIT COUNTRY = ARM AUS AUT AZE BHR BFL CHL TWN HRV CZE
               DNK ENG FIN GEO DEU HKG HUN IRN IRL ITA
               JPN KAZ KOR KWT LTU MLT MAR NLD NZL NIR
               NOR OMN POL PRT QAT ROM RUS SAU SRB SGP
               SVK SVN ESP SWE THA TUN TUR ARE USA YEM
               BWA HND YE6
               CAB COT CQU AAD ADU UFL UNC .
